@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2019-2024, by Samuel Williams.
+# Copyright, 2019-2025, by Samuel Williams.
 # Copyright, 2019, by Brian Morearty.
 # Copyright, 2020, by Bruno Sutic.
 # Copyright, 2023-2024, by Thomas Morgan.
@@ -224,11 +224,11 @@ module Protocol
 				return self
 			end
 			
-			def write_request(authority, method, path, version, headers)
+			def write_request(authority, method, target, version, headers)
 				open!
 				
-				@stream.write("#{method} #{path} #{version}\r\n")
-				@stream.write("host: #{authority}\r\n")
+				@stream.write("#{method} #{target} #{version}\r\n")
+				@stream.write("host: #{authority}\r\n") if authority
 				
 				write_headers(headers)
 			end
@@ -330,7 +330,11 @@ module Protocol
 				
 				@count += 1
 				
-				return headers.delete(HOST), method, path, version, headers, body
+				if block_given?
+					yield headers.delete(HOST), method, path, version, headers, body
+				else
+					return headers.delete(HOST), method, path, version, headers, body
+				end
 			end
 			
 			def read_response_line
@@ -366,7 +370,11 @@ module Protocol
 					@count += 1
 				end
 				
-				return version, status, reason, headers, body
+				if block_given?
+					yield version, status, reason, headers, body
+				else
+					return version, status, reason, headers, body
+				end
 			end
 			
 			def read_headers
